@@ -120,8 +120,9 @@ static int open_display (x11_instance_t * instance, int width, int height)
     visualTemplate.class = TrueColor;
 #endif
     visualTemplate.screen = DefaultScreen (instance->display);
+    visualTemplate.depth = DefaultDepth (instance->display, visualTemplate.screen);
     XvisualInfoTable = XGetVisualInfo (instance->display,
-				       VisualScreenMask | VisualClassMask,
+				       VisualScreenMask | VisualDepthMask | VisualClassMask,
 				       &visualTemplate, &number);
     if (XvisualInfoTable == NULL) {
 	fprintf (stderr, "No truecolor visual\n");
@@ -131,8 +132,9 @@ static int open_display (x11_instance_t * instance, int width, int height)
     /* find the visual with the highest depth */
     XvisualInfo = XvisualInfoTable;
     for (i = 1; i < number; i++)
-	if (XvisualInfoTable[i].depth > XvisualInfo->depth)
+	if (XvisualInfoTable[i].depth > XvisualInfo->depth) {
 	    XvisualInfo = XvisualInfoTable + i;
+    }
 
     instance->vinfo = *XvisualInfo;
     XFree (XvisualInfoTable);
