@@ -2,7 +2,7 @@
 #
 # Tool for displaying SPU graphics from DVD navigation streams
 #
-# $Id: gtkspu.c,v 1.19 2004/02/24 05:52:10 nemies Exp $
+# $Id: gtkspu.c 340 2006-10-28 07:41:47Z keescook $
 #
 # Copyright (C) 2002-2003 Kees Cook
 # kees@outflux.net, http://outflux.net/
@@ -507,7 +507,7 @@ int spu_packet_valid(file_buf * fb, off_t file_loc, uint8_t ** buf) {
         // freak out if dscq!=loc
         if (dscq != loc) {
             if (opt_debug)
-                printf("\tNext dscq is at 0x%04X instead of loc 0x%04X\n",
+                printf("\tNext dscq is at 0x%04zX instead of loc 0x%04zX\n",
                        dscq,loc);
             return SPU_PACKET_NOT_VALID;
         }
@@ -516,7 +516,7 @@ int spu_packet_valid(file_buf * fb, off_t file_loc, uint8_t ** buf) {
         next_dscq=GRAB_WORD(*buf,dscq+2);
 
         if (opt_debug)
-            printf("\tDSCQ 0x%04X (Next 0x%04X)\n",dscq,next_dscq);
+            printf("\tDSCQ 0x%04zX (Next 0x%04zX)\n",dscq,next_dscq);
 
         // spu's don't go backwards
         if (next_dscq<dscq) {
@@ -587,7 +587,7 @@ int spu_packet_valid(file_buf * fb, off_t file_loc, uint8_t ** buf) {
 
     // It sure LOOKS like a SPU...
     if (opt_debug)
-        printf("\tLooks good, with length %u\n",packet_len);
+        printf("\tLooks good, with length %zu\n",packet_len);
     return SPU_PACKET_VALID;
 }
 
@@ -912,7 +912,7 @@ int main(int argc, char *argv[])
     optind = handle_options(argc,argv);
 
     if (opt_version) {
-        printf("$Id: gtkspu.c,v 1.19 2004/02/24 05:52:10 nemies Exp $\n");
+        printf("$Id: gtkspu.c 340 2006-10-28 07:41:47Z keescook $\n");
         exit(0);
     }
 
@@ -965,7 +965,7 @@ int main(int argc, char *argv[])
                 exit(1);
             }
 
-            printf("Packet %d @ offset %"OFF_T_FORMAT" length %u\n",
+            printf("Packet %d @ offset %"OFF_T_FORMAT" length %zu\n",
                    packet,spu_packet_start,spu_len);
             while (spu_seq_loc != -1) {
                 spu_seq_loc = spu_run(buf, spu_packet_start,
